@@ -49,25 +49,24 @@ class Label(displayio.Group):
       Must include a capital M for measuring character size.
     :param str text: Text to display
     :param int max_glyphs: Unnecessary parameter (provided only for direct compability
-      with label.py)
+     with label.py)
     :param int color: Color of all text in RGB hex
     :param int background_color: Color of the background, use `None` for transparent
     :param double line_spacing: Line spacing of text to display
     :param boolean background_tight: Set `True` only if you want background box to tightly
-      surround text
+     surround text
     :param int padding_top: Additional pixels added to background bounding box at top
     :param int padding_bottom: Additional pixels added to background bounding box at bottom
     :param int padding_left: Additional pixels added to background bounding box at left
     :param int padding_right: Additional pixels added to background bounding box at right
     :param (double,double) anchor_point: Point that anchored_position moves relative to.
-      Tuple with decimal percentage of width and height.
-      (E.g. (0,0) is top left, (1.0, 0.5): is middle right.)
+     Tuple with decimal percentage of width and height.
+     (E.g. (0,0) is top left, (1.0, 0.5): is middle right.)
     :param (int,int) anchored_position: Position relative to the anchor_point. Tuple
-      containing x,y pixel coordinates.
+     containing x,y pixel coordinates.
     :param int scale: Integer value of the pixel scaling
     :param bool save_text: Set True to save the text string as a constant in the
-      label structure.  Set False to reduce memory use.
-    """
+     label structure.  Set False to reduce memory use."""
 
     # pylint: disable=unused-argument, too-many-instance-attributes, too-many-locals, too-many-arguments
     # pylint: disable=too-many-branches, no-self-use, too-many-statements
@@ -185,15 +184,11 @@ class Label(displayio.Group):
         if padding_right is not None:
             self._padding_right = max(0, padding_right)
         if anchor_point is not None:
-            self.anchor_point = anchor_point
+            self._anchor_point = anchor_point
         if anchored_position is not None:
             self._anchored_position = anchored_position
         if save_text is not None:
             self._save_text = save_text
-        if (
-            scale is not None
-        ):  # Scale will be defined in local_group (Note: self should have scale=1)
-            self.scale = scale  # call the setter
 
         # if text is not provided as a parameter (text is None), use the previous value.
         if (text is None) and self._save_text:
@@ -265,9 +260,8 @@ class Label(displayio.Group):
                 self._padding_top + y_offset,
             )
 
-            label_position_yoffset = int(  # To calibrate with label.py positioning
-                (self._font.get_glyph(ord("M")).height) / 2
-            )
+            # To calibrate with label.py positioning
+            label_position_yoffset = self._get_ascent() // 2
 
             self.tilegrid = displayio.TileGrid(
                 self.bitmap,
@@ -298,11 +292,39 @@ class Label(displayio.Group):
                 tight_box_y,
             )
 
+        if (
+            scale is not None
+        ):  # Scale will be defined in local_group (Note: self should have scale=1)
+            self.scale = scale  # call the setter
+
         self.anchored_position = (
             self._anchored_position
         )  # set the anchored_position with setter after bitmap is created, sets the
         # x,y positions of the label
 
+    def _get_ascent_descent(self):
+        if hasattr(self.font, "ascent"):
+            return self.font.ascent, self.font.descent
+
+        # check a few glyphs for maximum ascender and descender height
+        glyphs = "M j'"  # choose glyphs with highest ascender and lowest
+        try:
+            self._font.load_glyphs(glyphs)
+        except AttributeError:
+            # Builtin font doesn't have or need load_glyphs
+            pass
+        # descender, will depend upon font used
+        ascender_max = descender_max = 0
+        for char in glyphs:
+            this_glyph = self._font.get_glyph(ord(char))
+            if this_glyph:
+                ascender_max = max(ascender_max, this_glyph.height + this_glyph.dy)
+                descender_max = max(descender_max, -this_glyph.dy)
+        return ascender_max, descender_max
+
+    def _get_ascent(self):
+        return self._get_ascent_descent()[0]
+
     @staticmethod
     def _line_spacing_ypixels(font, line_spacing):
         # Note: Scaling is provided at the Group level
@@ -310,24 +332,7 @@ class Label(displayio.Group):
         return return_value
 
     def _text_bounding_box(self, text, font, line_spacing):
-
-        # This empirical approach checks several glyphs for maximum ascender and descender height
-        # (consistent with label.py)
-        glyphs = "M j'"  # choose glyphs with highest ascender and lowest
-        # descender, will depend upon font used
-
-        try:
-            font.load_glyphs(text + glyphs)
-        except AttributeError:
-            # ignore if font does not have load_glyphs
-            pass
-
-        ascender_max = descender_max = 0
-        for char in glyphs:
-            this_glyph = font.get_glyph(ord(char))
-            if this_glyph:
-                ascender_max = max(ascender_max, this_glyph.height + this_glyph.dy)
-                descender_max = max(descender_max, -this_glyph.dy)
+        ascender_max, descender_max = self._get_ascent_descent()
 
         lines = 1
 
@@ -339,7 +344,7 @@ class Label(displayio.Group):
         right = x_start
         top = bottom = y_start
 
-        y_offset_tight = int((font.get_glyph(ord("M")).height) / 2)
+        y_offset_tight = self._get_ascent() // 2
 
         newline = False
 
